--- draw.c.orig	2012-10-01 00:08:42.000000000 -0400
+++ draw.c	2012-10-01 00:04:35.000000000 -0400
@@ -8,12 +8,18 @@
 #include "jgraph.h"
 #include <stdio.h>
 #include <math.h>
+#include <string.h>
 
 static char real_eof = EOF;
 
-float ctop(val, axis)
-float val;
-Axis axis;
+static void draw_footer(Graphs, int);
+static void draw_header(Graphs, int, int);
+static void draw_arrow(float, float, float, float, Curve);
+static void draw_mark(float, float, Curve, Graph);
+static void draw_curve(Curve, Graph);
+static void draw_label(Label);
+
+float ctop(float val, Axis axis)
 {
   if (axis->is_lg) {
     if (val <= 0.0) {
@@ -29,9 +35,7 @@ Axis axis;
   }
 }
 
-float disttop(val, axis)
-float val;
-Axis axis;
+float disttop(float val, Axis axis)
 {
   if (axis->is_lg) {
     return FCPI * val;
@@ -40,16 +44,14 @@ Axis axis;
   }
 }
 
-float intop(val)
-float val;
+float intop(float val)
 {
   return FCPI * val;
 }
 
 #define MAXIMUM(a,b) ((a > b) ? a : b)
 
-draw_axis(a, other)
-Axis a, other;
+void draw_axis(Axis a, Axis other)
 {
   char orientation;
   Hash h;
@@ -114,16 +116,14 @@ Axis a, other;
 }
 
 
-draw_label(l)
-Label l;
+void draw_label(Label l)
 {
   if (l->label == CNULL) return;
   comment(l->label);
   print_label(l);
 }
 
-set_clip(g)
-Graph g;
+static void set_clip(Graph g)
 {
   comment("Setting Clip");
   printf("newpath\n");
@@ -133,8 +133,7 @@ Graph g;
   printf("  closepath clip newpath\n");
 }
 
-draw_curves(g)
-Graph g;
+static void draw_curves(Graph g)
 {
   Curve c;
 
@@ -148,9 +147,7 @@ Graph g;
   printf("\n");
 }
 
-draw_curve(c, g)
-Curve c;
-Graph g;
+void draw_curve(Curve c, Graph g)
 {
   Point p, px, py;
   int i, j;
@@ -267,10 +264,7 @@ Graph g;
   printf("\n");
 }
 
-draw_mark(x, y, c, g)
-float x, y;
-Curve c;
-Graph g;
+void draw_mark(float x, float y, Curve c, Graph g)
 {
   Point p;
   float ms0, ms1, scx, scy, trx, try;
@@ -499,9 +493,7 @@ Graph g;
   grestore();
 }
 
-draw_arrow(x1, y1, x2, y2, c)
-float x1, y1, x2, y2;
-Curve c;
+void draw_arrow(float x1, float y1, float x2, float y2, Curve c)
 {
   float dx, dy;
   float ms0;
@@ -539,8 +531,7 @@ Curve c;
   printf("\n");
 }
 
-draw_legend(g)
-Graph g;
+static void draw_legend(Graph g)
 {
   Curve c;
   Legend l;
@@ -603,8 +594,7 @@ Graph g;
   printf("\n");
 }
 
-draw_strings(g)
-Graph g;
+static void draw_strings(Graph g)
 {
   String s;
 
@@ -613,8 +603,7 @@ Graph g;
     draw_label(s->s);
 }
 
-draw_graph(g)
-Graph g;
+static void draw_graph(Graph g)
 {
   comment("Drawing New Graph");
   printf("%f %f translate\n", g->x_translate, g->y_translate);
@@ -634,10 +623,7 @@ Graph g;
 
 }
 
-draw_graphs(gs, pp, landscape)
-Graphs gs;
-int pp;
-int landscape;
+void draw_graphs(Graphs gs, int pp, int landscape)
 {
   Graphs gs_p;
   Graph g;
@@ -651,10 +637,7 @@ int landscape;
   }
 }
 
-draw_header(gs, pp, landscape)
-Graphs gs;
-int pp;
-int landscape;
+void draw_header(Graphs gs, int pp, int landscape)
 {
   FILE *f;
   char c;
@@ -685,7 +668,7 @@ int landscape;
         (((11.0 * FCPI) - (gs->bb[3] - gs->bb[1])) / 2.0) - gs->bb[1]);     
     }
   } else if (landscape) {
-    printf("%f 0 translate\n", -gs->bb[2] - gs->bb[0]);
+    printf("%f 0 translate\n", (double)(-gs->bb[2] - gs->bb[0]));
   }
   printf("1 setlinecap 1 setlinejoin\n");
   printf("0.700 setlinewidth\n");
@@ -746,9 +729,7 @@ int landscape;
   }
 }
 
-draw_footer(gs, pp)
-Graphs gs;
-int pp;
+void draw_footer(Graphs gs, int pp)
 {
   FILE *f;
   char c;
